==> mozilla-source-1.6.tar.bz2: mozilla/dom/src/base/nsScreen.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
#ifndef nsScreen_h___
#define nsScreen_h___

#include "nsIDOMScreen.h"
#include "nsISupports.h"
#include "nsIScriptContext.h"
#include "nsCOMPtr.h"

class nsIDocShell;
class nsIDeviceContext;
struct nsRect;

// Script "screen" object
class ScreenImpl : public nsIDOMScreen
{
public:
  ScreenImpl( nsIDocShell* aDocShell );
  virtual ~ScreenImpl();

  NS_IMETHOD SetDocShell(nsIDocShell* aDocShell);

  NS_DECL_ISUPPORTS

  NS_IMETHOD GetTop(PRInt32* aWidth);
  NS_IMETHOD GetLeft(PRInt32* aWidth);
  NS_IMETHOD GetWidth(PRInt32* aWidth);
  NS_IMETHOD GetHeight(PRInt32* aHeight);
  NS_IMETHOD GetPixelDepth(PRInt32* aPixelDepth);
  NS_IMETHOD GetColorDepth(PRInt32* aColorDepth);
  NS_IMETHOD GetAvailWidth(PRInt32* aAvailWidth);
  NS_IMETHOD GetAvailHeight(PRInt32* aAvailHeight);
  NS_IMETHOD GetAvailLeft(PRInt32* aAvailLeft);
  NS_IMETHOD GetAvailTop(PRInt32* aAvailTop);


protected:
  already_AddRefed<nsIDeviceContext> GetDeviceContext();
  nsresult GetRect(nsRect& aRect);
  nsresult GetAvailRect(nsRect& aRect);

  nsIDocShell* mDocShell; // Weak Reference
};

#endif /* nsScreen_h___ */

==> mozilla-source-1.7.5.tar.bz2: mozilla/dom/src/base/nsScreen.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
#ifndef nsScreen_h___
#define nsScreen_h___

#include "nsIDOMScreen.h"
#include "nsISupports.h"
#include "nsIScriptContext.h"
#include "nsCOMPtr.h"

class nsIDocShell;
class nsIDeviceContext;
struct nsRect;

// Script "screen" object
class ScreenImpl : public nsIDOMScreen
{
public:
  ScreenImpl( nsIDocShell* aDocShell );
  virtual ~ScreenImpl();

  NS_IMETHOD SetDocShell(nsIDocShell* aDocShell);

  NS_DECL_ISUPPORTS

  NS_IMETHOD GetTop(PRInt32* aWidth);
  NS_IMETHOD GetLeft(PRInt32* aWidth);
  NS_IMETHOD GetWidth(PRInt32* aWidth);
  NS_IMETHOD GetHeight(PRInt32* aHeight);
  NS_IMETHOD GetPixelDepth(PRInt32* aPixelDepth);
  NS_IMETHOD GetColorDepth(PRInt32* aColorDepth);
  NS_IMETHOD GetAvailWidth(PRInt32* aAvailWidth);
  NS_IMETHOD GetAvailHeight(PRInt32* aAvailHeight);
  NS_IMETHOD GetAvailLeft(PRInt32* aAvailLeft);
  NS_IMETHOD GetAvailTop(PRInt32* aAvailTop);


protected:
  nsIDeviceContext* GetDeviceContext();
  nsresult GetRect(nsRect& aRect);
  nsresult GetAvailRect(nsRect& aRect);

  nsIDocShell* mDocShell; // Weak Reference
};

#endif /* nsScreen_h___ */
